Switch to TL instead of ₺ for the TRY currency.

(cherry picked from commit c54e7799689c9180053771dfce37f2e25054febd)

Change-Id: I309b35a577e0634cc7adeb3bf458bbe9559dcd7a
diff --git a/data/curr/tr.txt b/data/curr/tr.txt
index eda15c7..f5881d3 100644
--- a/data/curr/tr.txt
+++ b/data/curr/tr.txt
@@ -900,7 +900,7 @@
             "Eski Türk Lirası",
         }
         TRY{
-            "₺",
+            "TL",
             "Türk Lirası",
         }
         TTD{
diff --git a/stubdata/icudt50l-all.dat b/stubdata/icudt50l-all.dat
index 5bad8e5..b3839fd 100644
--- a/stubdata/icudt50l-all.dat
+++ b/stubdata/icudt50l-all.dat
Binary files differ
diff --git a/stubdata/icudt50l-default.dat b/stubdata/icudt50l-default.dat
index 380208d..96d624a 100644
--- a/stubdata/icudt50l-default.dat
+++ b/stubdata/icudt50l-default.dat
Binary files differ
diff --git a/stubdata/regenerate.sh b/stubdata/regenerate.sh
index 32c8be5..d1e52d6 100755
--- a/stubdata/regenerate.sh
+++ b/stubdata/regenerate.sh
@@ -28,22 +28,27 @@
 # Make a temporary directory.
 rm -rf $ICU4C_DIR/tmp
 mkdir $ICU4C_DIR/tmp
-mkdir $ICU4C_DIR/tmp/region
 
-# Compile the region .txt files to .res files.
-# TODO: expand this to more than just the region files.
-cd $ICU4C_DIR/data/region
-for locale in *.txt ;
-do
-  $ICU_BIN/genrb -d $ICU4C_DIR/tmp/region ../../data/region/$locale
+# TODO: expand this to more than just the curr and region files.
+data_kinds="curr region"
+
+for data_kind in $data_kinds ; do
+  mkdir $ICU4C_DIR/tmp/$data_kind
+
+  # Compile the .txt files to .res files.
+  cd $ICU4C_DIR/data/$data_kind
+  for locale in *.txt ; do
+    $ICU_BIN/genrb -d $ICU4C_DIR/tmp/$data_kind ../../data/$data_kind/$locale
+  done
 done
 
 # Create a copy of the .dat file that uses the new .res files.
 cp $ICU4C_DIR/stubdata/icudt${ICU_VERSION}l-all.dat $ICU4C_DIR/tmp/icudt${ICU_VERSION}l.dat
 cd $ICU4C_DIR/tmp
-for res in region/*.res ;
-do
-  $ICU_BIN/icupkg -a $res icudt${ICU_VERSION}l.dat
+for data_kind in $data_kinds ; do
+  for res in $data_kind/*.res ; do
+    $ICU_BIN/icupkg -a $res icudt${ICU_VERSION}l.dat
+  done
 done
 
 # Make the modified .dat file the canonical copy.